Package: pandaR
Title: PANDA Algorithm
Version: 1.42.0
Author: Dan Schlauch, Joseph N. Paulson, Albert Young, John Quackenbush, Kimberly Glass
Maintainer: Joseph N. Paulson <paulson.joseph@gene.com>, Dan Schlauch <dschlauch@genospace.com>
Description: Runs PANDA, an algorithm for discovering novel network structure
    by combining information from multiple complementary data sources.
Depends: R (>= 3.0.0), methods, Biobase, BiocGenerics,
Imports: matrixStats, igraph, ggplot2, grid, reshape, plyr, RUnit,
        hexbin
Suggests: knitr, rmarkdown
biocViews: StatisticalMethod, GraphAndNetwork, Microarray,
        GeneRegulation, NetworkInference, GeneExpression,
        Transcription, Network
VignetteBuilder: knitr
License: GPL-2
LazyData: true
RoxygenNote: 6.1.1
git_url: https://git.bioconductor.org/packages/pandaR
git_branch: RELEASE_3_22
git_last_commit: 6b47106
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 05:37:13 UTC; biocbuild
