# Generated by roxygen2: do not edit by hand

S3method(print,panda)
export(calcDegree)
export(calcDegreeDifference)
export(importPandaMatlab)
export(multiplot)
export(panda)
export(plotCommunityDetection)
export(plotGraph)
export(plotZ)
export(plotZbyTF)
export(subnetwork)
export(summary.panda)
export(targetedGenes)
export(testMotif)
export(topedges)
import(BiocGenerics)
import(hexbin)
import(methods)
importFrom(Biobase,assayData)
importFrom(RUnit,checkTrue)
importFrom(ggplot2,"%+%")
importFrom(ggplot2,aes_string)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,scale_color_discrete)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,stat_binhex)
importFrom(ggplot2,xlab)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(graphics,title)
importFrom(grid,grid.layout)
importFrom(grid,grid.newpage)
importFrom(grid,pushViewport)
importFrom(grid,viewport)
importFrom(igraph,"E<-")
importFrom(igraph,"V<-")
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,fastgreedy.community)
importFrom(igraph,graph.data.frame)
importFrom(igraph,graph.incidence)
importFrom(igraph,groups)
importFrom(igraph,layout.bipartite)
importFrom(igraph,layout.fruchterman.reingold)
importFrom(igraph,membership)
importFrom(matrixStats,colSds)
importFrom(matrixStats,rowSds)
importFrom(plyr,ddply)
importFrom(reshape,melt.array)
importFrom(stats,aggregate)
importFrom(stats,cor)
importFrom(stats,pnorm)
importFrom(utils,read.delim)
