#' pandaR: Passing Messages between Biological Networks to Refine Predicted Interactions.
#'
#' The PANDA approach is to model the regulatory network as a bipartite network and estimate edge weights based on the evidence that information from a particular transcription factor i is successfully being passed to a particular gene j. This package provides a straightforward tool for applying this established method.
#' 
#' @docType package
#' @name pandaR
#' @importFrom RUnit checkTrue
#' @importFrom graphics title
#' @importFrom stats aggregate
#' @importFrom stats cor 
#' @importFrom stats pnorm
#' @importFrom utils read.delim
#' @import methods
#' @import BiocGenerics
NULL
#> NULL
